@@ -24,7 +24,7 @@ class AppInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: str
         :param Appkey: 应用key
@@ -77,7 +77,7 @@ class CardInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Iccid: 卡片ID
         :type Iccid: str
         :param Msisdn: 卡电话号码
@@ -150,6 +150,9 @@ class CardInfo(AbstractModel):
         :param CertificationState: 实名认证 0:无 1:未实名 2:已实名
 注意：此字段可能返回 null，表示取不到有效值。
         :type CertificationState: int
+        :param OtherData: 其他流量信息,流量分离统计其他流量
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OtherData: float
         """
         self.Iccid = None
         self.Msisdn = None
@@ -178,6 +181,7 @@ class CardInfo(AbstractModel):
         self.NeedSms = None
         self.Provider = None
         self.CertificationState = None
+        self.OtherData = None
 
 
     def _deserialize(self, params):
@@ -208,6 +212,7 @@ class CardInfo(AbstractModel):
         self.NeedSms = params.get("NeedSms")
         self.Provider = params.get("Provider")
         self.CertificationState = params.get("CertificationState")
+        self.OtherData = params.get("OtherData")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -223,7 +228,7 @@ class CardList(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Total: 卡片总数
         :type Total: str
         :param List: 卡片列表信息
@@ -257,7 +262,7 @@ class DescribeAppRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 物联卡应用ID
         :type Sdkappid: int
         """
@@ -281,7 +286,7 @@ class DescribeAppResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 应用信息详情
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.AppInfo`
@@ -305,7 +310,7 @@ class DescribeCardRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccid: 卡片ID
@@ -333,7 +338,7 @@ class DescribeCardResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 卡片详细信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.CardInfo`
@@ -357,7 +362,7 @@ class DescribeCardsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: str
         :param Offset: 偏移值
@@ -389,7 +394,7 @@ class DescribeCardsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 卡片列表信息
         :type Data: :class:`tencentcloud.ic.v20190307.models.CardList`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -406,13 +411,97 @@ class DescribeCardsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeSmsRequest(AbstractModel):
+    """DescribeSms请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Sdkappid: 应用ID
+        :type Sdkappid: int
+        :param Iccid: 卡片ID
+        :type Iccid: str
+        :param Msisdn: 卡片号码
+        :type Msisdn: str
+        :param SmsType: 短信类型
+        :type SmsType: int
+        :param BeginTime: 开始时间  YYYY-MM-DD HH:mm:ss
+        :type BeginTime: str
+        :param EndTime: 结束时间  YYYY-MM-DD HH:mm:ss
+        :type EndTime: str
+        :param Offset: 偏移量
+        :type Offset: int
+        :param Limit: 小于200
+        :type Limit: int
+        """
+        self.Sdkappid = None
+        self.Iccid = None
+        self.Msisdn = None
+        self.SmsType = None
+        self.BeginTime = None
+        self.EndTime = None
+        self.Offset = None
+        self.Limit = None
+
+
+    def _deserialize(self, params):
+        self.Sdkappid = params.get("Sdkappid")
+        self.Iccid = params.get("Iccid")
+        self.Msisdn = params.get("Msisdn")
+        self.SmsType = params.get("SmsType")
+        self.BeginTime = params.get("BeginTime")
+        self.EndTime = params.get("EndTime")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeSmsResponse(AbstractModel):
+    """DescribeSms返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Total: 总数
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Total: int
+        :param List: 短信列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type List: list of ResSms
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Total = None
+        self.List = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Total = params.get("Total")
+        if params.get("List") is not None:
+            self.List = []
+            for item in params.get("List"):
+                obj = ResSms()
+                obj._deserialize(item)
+                self.List.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class ModifyUserCardRemarkRequest(AbstractModel):
     """ModifyUserCardRemark请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccid: 物联卡ICCID
@@ -444,7 +533,7 @@ class ModifyUserCardRemarkResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -455,13 +544,68 @@ class ModifyUserCardRemarkResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class PayForExtendDataRequest(AbstractModel):
+    """PayForExtendData请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Iccid: 卡片ICCID
+        :type Iccid: str
+        :param ExtentData: 套外流量,单位MB
+        :type ExtentData: int
+        :param Sdkappid: 应用ID
+        :type Sdkappid: int
+        """
+        self.Iccid = None
+        self.ExtentData = None
+        self.Sdkappid = None
+
+
+    def _deserialize(self, params):
+        self.Iccid = params.get("Iccid")
+        self.ExtentData = params.get("ExtentData")
+        self.Sdkappid = params.get("Sdkappid")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class PayForExtendDataResponse(AbstractModel):
+    """PayForExtendData返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Data: 订单号
+        :type Data: :class:`tencentcloud.ic.v20190307.models.ResOrderIds`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = ResOrderIds()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
 class RenewCardsRequest(AbstractModel):
     """RenewCards请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccids: 续费的iccid
@@ -493,7 +637,7 @@ class RenewCardsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 续费成功的订单id
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.ResRenew`
@@ -511,13 +655,13 @@ class RenewCardsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class ResRenew(AbstractModel):
-    """云api 卡片续费
+class ResOrderIds(AbstractModel):
+    """订单ID集合
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param OrderIds: 每一张续费卡片的订单ID数组
 注意：此字段可能返回 null，表示取不到有效值。
         :type OrderIds: list of str
@@ -536,13 +680,103 @@ class ResRenew(AbstractModel):
         
 
 
+class ResRenew(AbstractModel):
+    """云api 卡片续费
+
+    """
+
+    def __init__(self):
+        r"""
+        :param OrderIds: 每一张续费卡片的订单ID数组
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OrderIds: list of str
+        """
+        self.OrderIds = None
+
+
+    def _deserialize(self, params):
+        self.OrderIds = params.get("OrderIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ResSms(AbstractModel):
+    """查询短信列表
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Iccid: 卡片ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Iccid: str
+        :param Msisdn: 卡片号码
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Msisdn: str
+        :param SdkAppid: 应用ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SdkAppid: int
+        :param Content: 短信内容
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Content: str
+        :param SmsType: 短信类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SmsType: int
+        :param SendTime: 发送时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SendTime: str
+        :param ReportTime: 推送时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ReportTime: str
+        :param Remark: SUCC：成功  FAIL 失败
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Remark: str
+        :param Status: 回执状态
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Status: int
+        """
+        self.Iccid = None
+        self.Msisdn = None
+        self.SdkAppid = None
+        self.Content = None
+        self.SmsType = None
+        self.SendTime = None
+        self.ReportTime = None
+        self.Remark = None
+        self.Status = None
+
+
+    def _deserialize(self, params):
+        self.Iccid = params.get("Iccid")
+        self.Msisdn = params.get("Msisdn")
+        self.SdkAppid = params.get("SdkAppid")
+        self.Content = params.get("Content")
+        self.SmsType = params.get("SmsType")
+        self.SendTime = params.get("SendTime")
+        self.ReportTime = params.get("ReportTime")
+        self.Remark = params.get("Remark")
+        self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SendMultiSmsRequest(AbstractModel):
     """SendMultiSms请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: str
         :param Iccids: 卡片列表
@@ -574,7 +808,7 @@ class SendMultiSmsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 短信流水数组
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: list of SmsRet
@@ -601,7 +835,7 @@ class SendSmsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Sdkappid: 应用ID
         :type Sdkappid: int
         :param Iccid: 卡片ID
@@ -633,7 +867,7 @@ class SendSmsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Data: 短信流水信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type Data: :class:`tencentcloud.ic.v20190307.models.SmsSid`
@@ -657,7 +891,7 @@ class SmsRet(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Code: 该iccid请求状态
         :type Code: str
         :param Msg: 短信发送返回信息
@@ -693,7 +927,7 @@ class SmsSid(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Iccid: 卡片ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type Iccid: str
